==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/db/d31/settings__widget_8h.js <==
var settings__widget_8h =
[
    [ "CustomCurrencyWidgets", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169", [
      [ "WID_CC_RATE_DOWN", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a5e8351d3eddb1bcc589dc095cf7c0bb9", null ],
      [ "WID_CC_RATE_UP", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a5ec948112ab73d639ff366047b3658e0", null ],
      [ "WID_CC_RATE", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169ae0071018c8e5a0617c3c9629a5da0ac7", null ],
      [ "WID_CC_SEPARATOR_EDIT", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a57b107089b0802d319f2404efc2af029", null ],
      [ "WID_CC_SEPARATOR", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169ac37c38cbf7d7d3150c58e7801f2ddc10", null ],
      [ "WID_CC_PREFIX_EDIT", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a66b1f939c25b06b63407be7dce8c6151", null ],
      [ "WID_CC_PREFIX", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a6634e8b9187fd0f138a357cffdc14dfa", null ],
      [ "WID_CC_SUFFIX_EDIT", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a55637b566ffe042abd1b20b1d2390768", null ],
      [ "WID_CC_SUFFIX", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169abb1e3c57f2a02c7e5eea9d09760dc233", null ],
      [ "WID_CC_YEAR_DOWN", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a236fa515d0dfe15d773e387c40b684fb", null ],
      [ "WID_CC_YEAR_UP", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169ac28c72d99f9b6d87b6c91a1002f96ef9", null ],
      [ "WID_CC_YEAR", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a2a32fed6834ded516f86ee6eaafa78d8", null ],
      [ "WID_CC_PREVIEW", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a5f40195f815aa29ba1305299a73f3d76", null ]
    ] ],
    [ "GameOptionsWidgets", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598", [
      [ "WID_GO_BACKGROUND", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598aacdf28b2f1dede199d58eda980ee07c5", null ],
      [ "WID_GO_CURRENCY_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a29cd8257875363c441b88d9fd380c518", null ],
      [ "WID_GO_DISTANCE_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a3a3f5e0706529e987ac240c0574c5d9b", null ],
      [ "WID_GO_ROADSIDE_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a7e47242895399d0dbcd6b114b74292df", null ],
      [ "WID_GO_TOWNNAME_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a2736a3214990d640818e9632e073c59e", null ],
      [ "WID_GO_AUTOSAVE_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598aa01195557541237080e8b73fbcda8f51", null ],
      [ "WID_GO_LANG_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a847aa2272f6fcdc7954ae183724a56bb", null ],
      [ "WID_GO_RESOLUTION_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a1abfc89182035b3f25527a3c38684313", null ],
      [ "WID_GO_FULLSCREEN_BUTTON", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598aed8aa27defc7f26ddc5a218c156ceb3e", null ],
      [ "WID_GO_GUI_ZOOM_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598aa9f3c001361437f28e6cb8784dc7e3b9", null ],
      [ "WID_GO_BASE_GRF_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a687d73cd5c31c6d8c06a2ab1b1889b99", null ],
      [ "WID_GO_BASE_GRF_STATUS", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a1e16439f4b47f9c448f7add30d91f2f1", null ],
      [ "WID_GO_BASE_GRF_TEXTFILE", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a5c261c36676237028e05da726e58231a", null ],
      [ "WID_GO_BASE_GRF_DESCRIPTION", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a2acebce1557363ad4b4f4fafb400873c", null ],
      [ "WID_GO_BASE_SFX_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598af4e35761c0f7f99b7bfa72a0b9ab2a34", null ],
      [ "WID_GO_BASE_SFX_TEXTFILE", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a4e3b073cbb01ddf3bebd0dacbecd05c1", null ],
      [ "WID_GO_BASE_SFX_DESCRIPTION", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a2d05eb4df8b8d9e4d90a2bde7b373ee6", null ],
      [ "WID_GO_BASE_MUSIC_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598ae3259ef477d1e32aeac938d74c513fab", null ],
      [ "WID_GO_BASE_MUSIC_STATUS", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598ac8ddbd2445858d54fb1f75fe8d97c04c", null ],
      [ "WID_GO_BASE_MUSIC_TEXTFILE", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598ac6c08b6c5554cbef188ab193edcde5f0", null ],
      [ "WID_GO_BASE_MUSIC_DESCRIPTION", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a10043764c393afe1e9c01e55395c4a50", null ]
    ] ],
    [ "GameSettingsWidgets", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5", [
      [ "WID_GS_FILTER", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5aef91a1ca8b4aaa61baaa38996bf1df69", null ],
      [ "WID_GS_OPTIONSPANEL", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a4a32ab3c05edb4bc427bcd8c78c48ab0", null ],
      [ "WID_GS_SCROLLBAR", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a9faf07f0d7f6829aef971a0a28ff206b", null ],
      [ "WID_GS_HELP_TEXT", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a57d02aba0358738646aab16ff7927a9a", null ],
      [ "WID_GS_EXPAND_ALL", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a358bfcd97dd2b4baa580288470a3abf2", null ],
      [ "WID_GS_COLLAPSE_ALL", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5ab8529f2cb7ad0f1547db571c5e6eb0b8", null ],
      [ "WID_GS_RESTRICT_CATEGORY", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a50daf2eeb4494f16dcee53043d82cefe", null ],
      [ "WID_GS_RESTRICT_TYPE", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a906a98ec033e046bdec06975ab93c2b4", null ],
      [ "WID_GS_RESTRICT_DROPDOWN", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a6048377a2994a64b81ec926add4036f7", null ],
      [ "WID_GS_TYPE_DROPDOWN", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a1e1cd147f4f21bfb87162c7693aa6acf", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/db/d31/settings__widget_8h.js <==
var settings__widget_8h =
[
    [ "CustomCurrencyWidgets", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169", [
      [ "WID_CC_RATE_DOWN", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a5e8351d3eddb1bcc589dc095cf7c0bb9", null ],
      [ "WID_CC_RATE_UP", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a5ec948112ab73d639ff366047b3658e0", null ],
      [ "WID_CC_RATE", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169ae0071018c8e5a0617c3c9629a5da0ac7", null ],
      [ "WID_CC_SEPARATOR_EDIT", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a57b107089b0802d319f2404efc2af029", null ],
      [ "WID_CC_SEPARATOR", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169ac37c38cbf7d7d3150c58e7801f2ddc10", null ],
      [ "WID_CC_PREFIX_EDIT", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a66b1f939c25b06b63407be7dce8c6151", null ],
      [ "WID_CC_PREFIX", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a6634e8b9187fd0f138a357cffdc14dfa", null ],
      [ "WID_CC_SUFFIX_EDIT", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a55637b566ffe042abd1b20b1d2390768", null ],
      [ "WID_CC_SUFFIX", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169abb1e3c57f2a02c7e5eea9d09760dc233", null ],
      [ "WID_CC_YEAR_DOWN", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a236fa515d0dfe15d773e387c40b684fb", null ],
      [ "WID_CC_YEAR_UP", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169ac28c72d99f9b6d87b6c91a1002f96ef9", null ],
      [ "WID_CC_YEAR", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a2a32fed6834ded516f86ee6eaafa78d8", null ],
      [ "WID_CC_PREVIEW", "db/d31/settings__widget_8h.html#a2666a2f93f8f1c7d44b3160975d53169a5f40195f815aa29ba1305299a73f3d76", null ]
    ] ],
    [ "GameOptionsWidgets", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598", [
      [ "WID_GO_BACKGROUND", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598aacdf28b2f1dede199d58eda980ee07c5", null ],
      [ "WID_GO_CURRENCY_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a29cd8257875363c441b88d9fd380c518", null ],
      [ "WID_GO_DISTANCE_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a3a3f5e0706529e987ac240c0574c5d9b", null ],
      [ "WID_GO_ROADSIDE_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a7e47242895399d0dbcd6b114b74292df", null ],
      [ "WID_GO_TOWNNAME_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a2736a3214990d640818e9632e073c59e", null ],
      [ "WID_GO_AUTOSAVE_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598aa01195557541237080e8b73fbcda8f51", null ],
      [ "WID_GO_LANG_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a847aa2272f6fcdc7954ae183724a56bb", null ],
      [ "WID_GO_RESOLUTION_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a1abfc89182035b3f25527a3c38684313", null ],
      [ "WID_GO_FULLSCREEN_BUTTON", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598aed8aa27defc7f26ddc5a218c156ceb3e", null ],
      [ "WID_GO_GUI_ZOOM_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598aa9f3c001361437f28e6cb8784dc7e3b9", null ],
      [ "WID_GO_BASE_GRF_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a687d73cd5c31c6d8c06a2ab1b1889b99", null ],
      [ "WID_GO_BASE_GRF_STATUS", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a1e16439f4b47f9c448f7add30d91f2f1", null ],
      [ "WID_GO_BASE_GRF_TEXTFILE", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a5c261c36676237028e05da726e58231a", null ],
      [ "WID_GO_BASE_GRF_DESCRIPTION", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a2acebce1557363ad4b4f4fafb400873c", null ],
      [ "WID_GO_BASE_SFX_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598af4e35761c0f7f99b7bfa72a0b9ab2a34", null ],
      [ "WID_GO_BASE_SFX_TEXTFILE", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a4e3b073cbb01ddf3bebd0dacbecd05c1", null ],
      [ "WID_GO_BASE_SFX_DESCRIPTION", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a2d05eb4df8b8d9e4d90a2bde7b373ee6", null ],
      [ "WID_GO_BASE_MUSIC_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598ae3259ef477d1e32aeac938d74c513fab", null ],
      [ "WID_GO_BASE_MUSIC_STATUS", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598ac8ddbd2445858d54fb1f75fe8d97c04c", null ],
      [ "WID_GO_BASE_MUSIC_TEXTFILE", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598ac6c08b6c5554cbef188ab193edcde5f0", null ],
      [ "WID_GO_BASE_MUSIC_DESCRIPTION", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a10043764c393afe1e9c01e55395c4a50", null ],
      [ "WID_GO_FONT_ZOOM_DROPDOWN", "db/d31/settings__widget_8h.html#a5825ea1e5b9518def76102eafd080598a6c78b89cbc402d71798bf80db9bfeb2b", null ]
    ] ],
    [ "GameSettingsWidgets", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5", [
      [ "WID_GS_FILTER", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5aef91a1ca8b4aaa61baaa38996bf1df69", null ],
      [ "WID_GS_OPTIONSPANEL", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a4a32ab3c05edb4bc427bcd8c78c48ab0", null ],
      [ "WID_GS_SCROLLBAR", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a9faf07f0d7f6829aef971a0a28ff206b", null ],
      [ "WID_GS_HELP_TEXT", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a57d02aba0358738646aab16ff7927a9a", null ],
      [ "WID_GS_EXPAND_ALL", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a358bfcd97dd2b4baa580288470a3abf2", null ],
      [ "WID_GS_COLLAPSE_ALL", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5ab8529f2cb7ad0f1547db571c5e6eb0b8", null ],
      [ "WID_GS_RESTRICT_CATEGORY", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a50daf2eeb4494f16dcee53043d82cefe", null ],
      [ "WID_GS_RESTRICT_TYPE", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a906a98ec033e046bdec06975ab93c2b4", null ],
      [ "WID_GS_RESTRICT_DROPDOWN", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a6048377a2994a64b81ec926add4036f7", null ],
      [ "WID_GS_TYPE_DROPDOWN", "db/d31/settings__widget_8h.html#adf9ed483c5eb410c5fb8c4b814d300d5a1e1cd147f4f21bfb87162c7693aa6acf", null ]
    ] ]
];
